/*-------------------------------------------------------------------------*/
/* colordefs.h 								   */
/* Copyright (c) 2002  Tim Edwards, Johns Hopkins University       	   */
/*-------------------------------------------------------------------------*/

/*-------------------------------------------------------------------------*/
/* Add colors here as needed. 						   */
/* Reflect all changes in the resource manager, xcircuit.c		   */
/* And ApplicationDataPtr in xcircuit.h					   */
/*-------------------------------------------------------------------------*/

#define NUMBER_OF_COLORS	16

#define BACKGROUND	appcolors[0]
#define FOREGROUND	appcolors[1]
#define SELECTCOLOR     appcolors[2]
#define QUERYCOLOR	appcolors[3] 
#define FILTERCOLOR	appcolors[4] 
#define GRIDCOLOR	appcolors[5]
#define SNAPCOLOR	appcolors[6]
#define AXESCOLOR	appcolors[7]
#define OFFBUTTONCOLOR	appcolors[8]
#define AUXCOLOR	appcolors[9]
#define BARCOLOR	appcolors[10]
#define PARAMCOLOR	appcolors[11]

/* The rest of the colors are layout colors, not GUI colors */

#define BBOXCOLOR	appcolors[12]
#define LOCALPINCOLOR	appcolors[13]
#define GLOBALPINCOLOR	appcolors[14]
#define INFOLABELCOLOR	appcolors[15]

#define DEFAULTCOLOR	-1		/* Inherits color of parent */
#define DOFORALL	-2		/* All elements inherit same color */
#define DOSUBSTRING	-3		/* Only selected substring drawn */
					/* in the SELECTCOLOR		*/

/*-------------------------------------------------------------------------*/
